@@ -841,7 +841,7 @@ error:
 	return -1;
 }
 
-/* called with call locked in W or R with ps->in_lock held */
+/* called with call locked in W or R with ps->lock held */
 int dtls(stream_fd *sfd, const str *s, const endpoint_t *fsin) {
 	struct packet_stream *ps = sfd->stream;
 	int ret;
@@ -889,22 +889,16 @@ int dtls(stream_fd *sfd, const str *s, const endpoint_t *fsin) {
 	else if (ret == 1) {
 		/* connected! */
 		dret = 1;
-		mutex_lock(&ps->out_lock); // nested lock!
 		if (dtls_setup_crypto(ps, d))
 			{} /* XXX ?? */
-		mutex_unlock(&ps->out_lock);
 
 		if (PS_ISSET(ps, RTP) && PS_ISSET(ps, RTCP) && ps->rtcp_sibling
 				&& MEDIA_ISSET(ps->media, RTCP_MUX)
 				&& ps->rtcp_sibling != ps)
 		{
-			// nested locks!
-			mutex_lock(&ps->rtcp_sibling->in_lock);
-			mutex_lock(&ps->rtcp_sibling->out_lock);
+			LOCK(&ps->rtcp_sibling->lock);
 			if (dtls_setup_crypto(ps->rtcp_sibling, d))
 				{} /* XXX ?? */
-			mutex_unlock(&ps->rtcp_sibling->out_lock);
-			mutex_unlock(&ps->rtcp_sibling->in_lock);
 		}
 	}
 
